#include <stdio.h>
#include <string.h>
#include <math.h>
#include "config.h"

double	skew(int n, double s2, double s3)
{
	/* skewness */
	return s3 / (n * sqrt(s2 / n) * sqrt(s2 / n) * sqrt(s2 / n));
}

double	kurt(int n, double s2, double s4)
{
	/* kurtosis */
	return s4 / (n * sqrt(s2 / n) * sqrt(s2 / n) * sqrt(s2 / n) * sqrt(s2 / n));
}

double	sdev(int n, double s2)
{
	/* standard deviation */
	return sqrt(s2 / (n - 1));
}

double	serr(int n, double s2)
{
	/* standard error */
	return sdev(n, s2) / sqrt(n);
}

double	cvar(int n, double s1, double s2)
{
	/* 
		 coefficient of variation -- Mizutani (1983:44)
		 ϡѰ۷=ʬ/ʿ*100ǡɽǤ롣
	*/
	if (s1 != 0)
		return 100 * sdev(n, s2) / s1;
	else
		return 0;
}

double	tvar(int n, double s1, double s2)
{
	/* tasseido of variation -- Mizutani (1983:64)  */
	if (s1 != 0)
		return 100 * serr(n, s2) / s1;
	else
		return 0;
}

double	rlo(int n, double s1, double s2, double k)
{
	/* reliable interval which is lower (Mizuno, Hitoshi)*/
	if (k == 0)
		k = 2.6; /* default */
	return ((s1 - serr(n,s2) * k) * 100) / 100;
}


double	rup(int n, double s1, double s2, double k)
{
	/* reliable interval which is upper (Mizuno, Hitoshi: Tchevichev)*/
	if (k == 0)
		k = 2.6; /* default */
	return ((s1 + serr(n,s2) * k) * 100) / 100;
}





